@@ -28,7 +28,7 @@ def escape(s):
 def t(arg, *args, **kwargs):
     _name = re.compile('^(\w+?)(?:\.|#|\:|\[|$)')
     _classes = re.compile('\.([a-zA-Z0-9\-_]+)')
-    _id = re.compile('\#(\w+)')
+    _id = re.compile("""#(\w+)(?=([^"']*"'[^"']*"')*[^"']*$)""")
     _unnamed_attrs = re.compile('\:(\w+)')
     _named_attrs0 = re.compile("""\[([a-zA-Z0-9\-\_]+?)=(.+?)\]""")
     _named_attrs1 = re.compile("""\[([a-zA-Z0-9\-\_]+?)=\"(.+?)\"\]""")
@@ -46,7 +46,7 @@ def t(arg, *args, **kwargs):
     unnamed_attributes = tag_unnamed_attrs
     named_attributes = {k: v for k, v in tag_named_attrs}
     if tag_id:
-        attributes['id'] = tag_id[0]
+        attributes['id'] = tag_id[0][0]
 
     classes = ' '.join(tag_classes)
 
